
{-# LANGUAGE NoImplicitPrelude       #-}

module Main where

import Data.Set as Set
import Data.String.Conversions (cs)
import Data.Text (Text)
import qualified Eigen.Matrix as Matrix
import Graph.BAC.ProxemyOptim
import Graph.FGL
import Graph.Types
import Graph.Tools.Random
import Prelude (String)
import Protolude
import Graph.BAC.ProxemyOptim
import Test.Hspec
import qualified Data.IntMap                       as Dict
import qualified Eigen.SparseMatrix as SMatrix
import qualified Prelude as Prelude
import qualified Data.List as List


main :: IO ()
main = hspec $ do
  describe "Graph Toy first test" $ do
    let 

        edges_test :: [(Int,Int)]
        edges_test=[(0,1),(0,2),(0,4),(0,5),(0,3),(0,6)
                   ,(1,2),(1,3),(2,3),(4,5),(4,6),(5,6)
                   ,(7,8),(7,3),(7,4),(8,2),(8,5)
                   ]

        clustering_result =
          ClusteringIs { parts = Dict.fromList [(0, Set.fromList [0,4,5,6])
                                               ,(1, Set.fromList [1,2,3])
                                               ,(7, Set.fromList [7,8])]
                       , index = Dict.fromList [(0,0),(1,1),(2,1)
                                               ,(3,1),(4,0),(5,0)
                                               ,(6,0),(7,7),(8,7)
                                               ]
                       , score = 3.0558391780792453
                       , mode = Part
                       }

        g :: Graph () ()
        g = mkGraphUfromEdges edges_test

        result = withG g (identity  . (clusteringOptim 3 Conf))
    it "Graph Toy test exact result" $ do
      shouldBe True (result == clustering_result)

{-
  m <- randomAdjacency
  describe "Random Matrix of fixed size (TODO dynamic size)" $ do
    let
      g :: Graph () ()
      g = mkGraphUfromEdges
        $ List.map (\(x,y,_) -> (x,y))
        $ SMatrix.toList m
      result = withG g (parts  . (clusteringOptim 3 Conf))
    it "Random test, checking clustering size" $ do
      shouldBe True (let n = (Dict.size result) in n > 1 && n < 10)
-}
